==> zzyj-outputvalcount-impl-3.0.0-20230616.073044-189-sources.jar: com/ejianc/business/appliances/bean/TestInspectionEntity.java <==
package com.ejianc.business.appliances.bean;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 器具-试验检验台账
 *
 * @author generator
 *
 */
@TableName("t_outputvalcount_appliances_test_inspection_report")
public class TestInspectionEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;

    @TableField(value="bill_code")
    private String billCode; // 单据编码
    @TableField(value="org_id")
    private Long orgId; // 组织id
    @TableField(value="org_name")
    private String orgName; // 组织名称
    @TableField(value="bill_state")
    private Integer billState; // 单据状态
    @TableField(value="create_user_name")
    private String createUserName; // 编制人
    @TableField(value="operator_id")
    private Long operatorId; // 经办人ID
    @TableField(value="operator_name")
    private String operatorName; // 经办人姓名
    @TableField(value="update_user_name")
    private String updateUserName; // 修改者
    @TableField(value="remark")
    private String remark; // 备注
    @TableField(value="patrol_group_id")
    private Long patrolGroupId; // 所属巡检组id
    @TableField(value="patrol_group")
    private String patrolGroup; // 所属巡检组：1、巡检一组 2、巡检二组 3、巡检三组
    @TableField(value="project_id")
    private Long projectId; // 工程名称id
    @TableField(value="project_name")
    private String projectName; // 工程名称
    @TableField(value="technology_id")
    private Long technologyId; // 项目技术负责人
    @TableField(value="technology_name")
    private String technologyName; // 项目技术负责人名称
    @TableField(value="engineering_type_id")
    private Long engineeringTypeId; // 工程类别
    @TableField(value="engineering_type")
    private String engineeringType; // 工程类型：1、单体工程 2、群体工程 3、线性工程
    @TableField(value="testers_id")
    private Long testersId; // 试验员
    @TableField(value="testers_name")
    private String testersName; // 试验员名称
    @TableField(value="test_num")
    private Integer testNum; // 数量
    @TableField(value="test_batch")
    private String testBatch; // 批量
    @TableField(value="test_name")
    private String testName; // 样品名称
    @TableField(value="test_type")
    private Long testType; // 实验材料类型
    @TableField(value="test_type_name")
    private String testTypeName; // 实验材料类型名称
    @TableField(value="sampling_date")
    private Date samplingDate; // 取样日期
    @TableField(value="report_date")
    private Date reportDate; // 报告日期
    @TableField(value="report_code")
    private String reportCode; // 报告编号
    @TableField(value="sampling_part")
    private String samplingPart; // 工程(取样)部位
    @TableField(value="product_manufactor")
    private String productManufactor; // 生产厂家
    @TableField(value="welding_method")
    private String weldingMethod; // 焊接或作业方式
    @TableField(value="spec")
    private String spec; // 规格型号

    @TableField(value="result_type")
    private String resultType; // 结果状态（1：正常 2：异常）
    @TableField(value="result_progress")
    private String resultProgress; // 结果进展（1：已出 2：未返还）



    public String getBillCode() {
        return billCode;
    }

    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }
    public Long getOrgId() {
        return orgId;
    }

    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }
    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }
    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }
    public String getCreateUserName() {
        return createUserName;
    }

    public void setCreateUserName(String createUserName) {
        this.createUserName = createUserName;
    }
    public Long getOperatorId() {
        return operatorId;
    }

    public void setOperatorId(Long operatorId) {
        this.operatorId = operatorId;
    }
    public String getOperatorName() {
        return operatorName;
    }

    public void setOperatorName(String operatorName) {
        this.operatorName = operatorName;
    }
    public String getUpdateUserName() {
        return updateUserName;
    }

    public void setUpdateUserName(String updateUserName) {
        this.updateUserName = updateUserName;
    }
    public String getRemark() {
        return remark;
    }

    public void setRemark(String remark) {
        this.remark = remark;
    }
    public Long getPatrolGroupId() {
        return patrolGroupId;
    }

    public void setPatrolGroupId(Long patrolGroupId) {
        this.patrolGroupId = patrolGroupId;
    }
    public String getPatrolGroup() {
        return patrolGroup;
    }

    public void setPatrolGroup(String patrolGroup) {
        this.patrolGroup = patrolGroup;
    }
    public Long getProjectId() {
        return projectId;
    }

    public void setProjectId(Long projectId) {
        this.projectId = projectId;
    }
    public String getProjectName() {
        return projectName;
    }

    public void setProjectName(String projectName) {
        this.projectName = projectName;
    }
    public Long getTechnologyId() {
        return technologyId;
    }

    public void setTechnologyId(Long technologyId) {
        this.technologyId = technologyId;
    }
    public String getTechnologyName() {
        return technologyName;
    }

    public void setTechnologyName(String technologyName) {
        this.technologyName = technologyName;
    }
    public Long getEngineeringTypeId() {
        return engineeringTypeId;
    }

    public void setEngineeringTypeId(Long engineeringTypeId) {
        this.engineeringTypeId = engineeringTypeId;
    }
    public String getEngineeringType() {
        return engineeringType;
    }

    public void setEngineeringType(String engineeringType) {
        this.engineeringType = engineeringType;
    }
    public Long getTestersId() {
        return testersId;
    }

    public void setTestersId(Long testersId) {
        this.testersId = testersId;
    }
    public String getTestersName() {
        return testersName;
    }

    public void setTestersName(String testersName) {
        this.testersName = testersName;
    }

    public Integer getTestNum() {
        return testNum;
    }

    public void setTestNum(Integer testNum) {
        this.testNum = testNum;
    }

    public String getTestBatch() {
        return testBatch;
    }

    public void setTestBatch(String testBatch) {
        this.testBatch = testBatch;
    }

    public String getTestName() {
        return testName;
    }

    public void setTestName(String testName) {
        this.testName = testName;
    }

    public Long getTestType() {
        return testType;
    }

    public void setTestType(Long testType) {
        this.testType = testType;
    }

    public String getTestTypeName() {
        return testTypeName;
    }

    public void setTestTypeName(String testTypeName) {
        this.testTypeName = testTypeName;
    }

    public Date getSamplingDate() {
        return samplingDate;
    }

    public void setSamplingDate(Date samplingDate) {
        this.samplingDate = samplingDate;
    }

    public Date getReportDate() {
        return reportDate;
    }

    public void setReportDate(Date reportDate) {
        this.reportDate = reportDate;
    }

    public String getReportCode() {
        return reportCode;
    }

    public void setReportCode(String reportCode) {
        this.reportCode = reportCode;
    }

    public String getSamplingPart() {
        return samplingPart;
    }

    public void setSamplingPart(String samplingPart) {
        this.samplingPart = samplingPart;
    }

    public String getProductManufactor() {
        return productManufactor;
    }

    public void setProductManufactor(String productManufactor) {
        this.productManufactor = productManufactor;
    }

    public String getWeldingMethod() {
        return weldingMethod;
    }

    public void setWeldingMethod(String weldingMethod) {
        this.weldingMethod = weldingMethod;
    }

    public String getSpec() {
        return spec;
    }

    public void setSpec(String spec) {
        this.spec = spec;
    }

    public String getResultType() {
        return resultType;
    }

    public void setResultType(String resultType) {
        this.resultType = resultType;
    }

    public String getResultProgress() {
        return resultProgress;
    }

    public void setResultProgress(String resultProgress) {
        this.resultProgress = resultProgress;
    }
}

==> zzyj-outputvalcount-impl-3.0.0-20230621.103639-194-sources.jar: com/ejianc/business/appliances/bean/TestInspectionEntity.java <==
package com.ejianc.business.appliances.bean;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 器具-试验检验台账
 *
 * @author generator
 *
 */
@TableName("t_outputvalcount_appliances_test_inspection_report")
public class TestInspectionEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;

    @TableField(value="bill_code")
    private String billCode; // 单据编码
    @TableField(value="org_id")
    private Long orgId; // 组织id
    @TableField(value="org_name")
    private String orgName; // 组织名称
    @TableField(value="bill_state")
    private Integer billState; // 单据状态
    @TableField(value="create_user_name")
    private String createUserName; // 编制人
    @TableField(value="operator_id")
    private Long operatorId; // 经办人ID
    @TableField(value="operator_name")
    private String operatorName; // 经办人姓名
    @TableField(value="update_user_name")
    private String updateUserName; // 修改者
    @TableField(value="remark")
    private String remark; // 备注
    @TableField(value="patrol_group_id")
    private Long patrolGroupId; // 所属巡检组id
    @TableField(value="patrol_group")
    private String patrolGroup; // 所属巡检组：1、巡检一组 2、巡检二组 3、巡检三组
    @TableField(value="project_id")
    private Long projectId; // 工程名称id
    @TableField(value="project_name")
    private String projectName; // 工程名称
    @TableField(value="technology_id")
    private Long technologyId; // 项目技术负责人
    @TableField(value="technology_name")
    private String technologyName; // 项目技术负责人名称
    @TableField(value="engineering_type_id")
    private Long engineeringTypeId; // 工程类别
    @TableField(value="engineering_type")
    private String engineeringType; // 工程类型：1、单体工程 2、群体工程 3、线性工程
    @TableField(value="testers_id")
    private Long testersId; // 试验员
    @TableField(value="testers_name")
    private String testersName; // 试验员名称
    @TableField(value="test_num")
    private String testNum; // 数量
    @TableField(value="test_batch")
    private String testBatch; // 批量
    @TableField(value="test_name")
    private String testName; // 样品名称
    @TableField(value="test_type")
    private Long testType; // 实验材料类型
    @TableField(value="test_type_name")
    private String testTypeName; // 实验材料类型名称
    @TableField(value="sampling_date")
    private Date samplingDate; // 取样日期
    @TableField(value="report_date")
    private Date reportDate; // 报告日期
    @TableField(value="report_code")
    private String reportCode; // 报告编号
    @TableField(value="sampling_part")
    private String samplingPart; // 工程(取样)部位
    @TableField(value="product_manufactor")
    private String productManufactor; // 生产厂家
    @TableField(value="welding_method")
    private String weldingMethod; // 焊接或作业方式
    @TableField(value="spec")
    private String spec; // 规格型号

    @TableField(value="result_type")
    private String resultType; // 结果状态（1：正常 2：异常）
    @TableField(value="result_progress")
    private String resultProgress; // 结果进展（1：已出 2：未返还）



    public String getBillCode() {
        return billCode;
    }

    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }
    public Long getOrgId() {
        return orgId;
    }

    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }
    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }
    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }
    public String getCreateUserName() {
        return createUserName;
    }

    public void setCreateUserName(String createUserName) {
        this.createUserName = createUserName;
    }
    public Long getOperatorId() {
        return operatorId;
    }

    public void setOperatorId(Long operatorId) {
        this.operatorId = operatorId;
    }
    public String getOperatorName() {
        return operatorName;
    }

    public void setOperatorName(String operatorName) {
        this.operatorName = operatorName;
    }
    public String getUpdateUserName() {
        return updateUserName;
    }

    public void setUpdateUserName(String updateUserName) {
        this.updateUserName = updateUserName;
    }
    public String getRemark() {
        return remark;
    }

    public void setRemark(String remark) {
        this.remark = remark;
    }
    public Long getPatrolGroupId() {
        return patrolGroupId;
    }

    public void setPatrolGroupId(Long patrolGroupId) {
        this.patrolGroupId = patrolGroupId;
    }
    public String getPatrolGroup() {
        return patrolGroup;
    }

    public void setPatrolGroup(String patrolGroup) {
        this.patrolGroup = patrolGroup;
    }
    public Long getProjectId() {
        return projectId;
    }

    public void setProjectId(Long projectId) {
        this.projectId = projectId;
    }
    public String getProjectName() {
        return projectName;
    }

    public void setProjectName(String projectName) {
        this.projectName = projectName;
    }
    public Long getTechnologyId() {
        return technologyId;
    }

    public void setTechnologyId(Long technologyId) {
        this.technologyId = technologyId;
    }
    public String getTechnologyName() {
        return technologyName;
    }

    public void setTechnologyName(String technologyName) {
        this.technologyName = technologyName;
    }
    public Long getEngineeringTypeId() {
        return engineeringTypeId;
    }

    public void setEngineeringTypeId(Long engineeringTypeId) {
        this.engineeringTypeId = engineeringTypeId;
    }
    public String getEngineeringType() {
        return engineeringType;
    }

    public void setEngineeringType(String engineeringType) {
        this.engineeringType = engineeringType;
    }
    public Long getTestersId() {
        return testersId;
    }

    public void setTestersId(Long testersId) {
        this.testersId = testersId;
    }
    public String getTestersName() {
        return testersName;
    }

    public void setTestersName(String testersName) {
        this.testersName = testersName;
    }

    public String getTestNum() {
        return testNum;
    }

    public void setTestNum(String testNum) {
        this.testNum = testNum;
    }

    public String getTestBatch() {
        return testBatch;
    }

    public void setTestBatch(String testBatch) {
        this.testBatch = testBatch;
    }

    public String getTestName() {
        return testName;
    }

    public void setTestName(String testName) {
        this.testName = testName;
    }

    public Long getTestType() {
        return testType;
    }

    public void setTestType(Long testType) {
        this.testType = testType;
    }

    public String getTestTypeName() {
        return testTypeName;
    }

    public void setTestTypeName(String testTypeName) {
        this.testTypeName = testTypeName;
    }

    public Date getSamplingDate() {
        return samplingDate;
    }

    public void setSamplingDate(Date samplingDate) {
        this.samplingDate = samplingDate;
    }

    public Date getReportDate() {
        return reportDate;
    }

    public void setReportDate(Date reportDate) {
        this.reportDate = reportDate;
    }

    public String getReportCode() {
        return reportCode;
    }

    public void setReportCode(String reportCode) {
        this.reportCode = reportCode;
    }

    public String getSamplingPart() {
        return samplingPart;
    }

    public void setSamplingPart(String samplingPart) {
        this.samplingPart = samplingPart;
    }

    public String getProductManufactor() {
        return productManufactor;
    }

    public void setProductManufactor(String productManufactor) {
        this.productManufactor = productManufactor;
    }

    public String getWeldingMethod() {
        return weldingMethod;
    }

    public void setWeldingMethod(String weldingMethod) {
        this.weldingMethod = weldingMethod;
    }

    public String getSpec() {
        return spec;
    }

    public void setSpec(String spec) {
        this.spec = spec;
    }

    public String getResultType() {
        return resultType;
    }

    public void setResultType(String resultType) {
        this.resultType = resultType;
    }

    public String getResultProgress() {
        return resultProgress;
    }

    public void setResultProgress(String resultProgress) {
        this.resultProgress = resultProgress;
    }
}
